[PC-BSD Commits] r7991 - in pcbsd/current: src-qt4/pc-xgui/resources/bin system-overlay/etc system-overlay/usr/local/etc/rc.d
svn at pcbsd.org
svn at pcbsd.org
Sat Nov 6 15:03:31 PDT 2010
Author: kris
Date: 2010-11-06 15:03:31 -0700 (Sat, 06 Nov 2010)
New Revision: 7991
Added:
pcbsd/current/system-overlay/usr/local/etc/rc.d/gdm
Modified:
pcbsd/current/src-qt4/pc-xgui/resources/bin/rundetect.sh
pcbsd/current/system-overlay/etc/ttys
Log:
Added the glue to use gdm with the display setup wizard
Modified: pcbsd/current/src-qt4/pc-xgui/resources/bin/rundetect.sh
===================================================================
--- pcbsd/current/system-overlay/etc/ttys 2010-11-06 21:29:19 UTC (rev 7990)
+++ pcbsd/current/system-overlay/etc/ttys 2010-11-06 22:03:31 UTC (rev 7991)
@@ -41,7 +41,7 @@
ttyv5 "/usr/libexec/getty Pc" cons25 on secure
ttyv6 "/usr/libexec/getty Pc" cons25 on secure
ttyv7 "/usr/libexec/getty Pc" cons25 on secure
-ttyv8 "/usr/PCBSD/bin/pdm" xterm on secure
+#ttyv8 "/usr/PCBSD/bin/pdm" xterm on secure
# Serial terminals
# The 'dialup' keyword identifies dialin lines to login, fingerd etc.
ttyd0 "/usr/libexec/getty std.9600" dialup off secure
Property changes on: pcbsd/current/system-overlay/usr/local/etc/rc.d/gdm
___________________________________________________________________
Added: svn:executable
+ *
More information about the Commits
mailing list
--- pcbsd/current/src-qt4/pc-xgui/resources/bin/rundetect.sh 2010-11-06 21:29:19 UTC (rev 7990)
+++ pcbsd/current/src-qt4/pc-xgui/resources/bin/rundetect.sh 2010-11-06 22:03:31 UTC (rev 7991)
@@ -1,7 +1,7 @@
#!/bin/sh
# xorg-gui startup script
# Copyright 2009 PC-BSD Software
# Descr: This script is called by /etc/ttys to run the first time X setup
# wizard. It allows the user to select a resolution / refresh rate and
# test it before continuing into the normal KDE GUI.
###############################################################################
@@ -259,8 +259,12 @@
done
-# Copy over the right ttys file now
-cp ${PROGDIR}/conf/ttys.normal /etc/ttys
+# Make sure gdm is enabled
+cat /etc/rc.conf | grep 'gdm_enable' >/dev/null 2>/dev/null
+if [ "$?" != "0" ] ; then
+ echo 'gdm_enable="YES"' >>/etc/rc.conf
+ /usr/local/etc/rc.d/gdm start &
+fi
rm /root/.xinitrc >/dev/null 2>/dev/null
# Check if we need to save an existing .xinitrc file
Modified: pcbsd/current/system-overlay/etc/ttys
@@ -1,7 +1,7 @@
# xorg-gui startup script
# Copyright 2009 PC-BSD Software
-# Descr: This script is called by /etc/ttys to run the first time X setup
+# Descr: This script is called by /usr/local/etc/rc.d/gdm to run the time X setup
# wizard. It allows the user to select a resolution / refresh rate and
# test it before continuing into the normal KDE GUI.
===================================================================